package com.lzmispt.data.resource.service.datasync.impl.handle;

package .tmp;

import com.lzmispt.core.entity.dto.querymodel.QueryModelDTO;
import com.lzmispt.core.entity.dto.querymodel.SortModelDTO;
import com.lzmispt.data.center.entity.dto.databasestruct.DBTableDTO;
import com.lzmispt.data.resource.client.DataStandardClient;
import com.lzmispt.data.resource.entity.vo.datasync.DataSourceTableTreeVO;
import com.lzmispt.data.resource.service.datasync.impl.handle.AbstrcatDataSyncDatabase;
import com.lzmispt.dcbase.databasestruct.DataStructProvider;
import com.lzmispt.dcbase.dcconst.DCConst;
import com.lzmispt.framework.fconst.FrameConst;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

@Service
public class MysqlDataSyncDatabaseHandler extends AbstrcatDataSyncDatabase {
  @Autowired
  DataStandardClient dataStandardClient;
  
  public List<DataSourceTableTreeVO> getDataBaseList(Long dataSourceId, String platCode, String tokenId, Boolean isEnableCdc) {
    DataStructProvider dataStructProvider = getDataStructProvider(dataSourceId, platCode, tokenId, null, null);
    List<String> dataBaseNameList = (List<String>)this.dataStandardClient.getDataBaseNameList(dataStructProvider.currentDataSource, platCode, tokenId).getObj();
    List<DataSourceTableTreeVO> dataSourceTableTreeList = (List<DataSourceTableTreeVO>)dataBaseNameList.stream().map(dataBaseName -> buildDataSourceTableVO(dataBaseName, null, null, dataSourceId, dataStructProvider.getDbType(), DCConst.DirectoryType.DATABASE)).collect(Collectors.toList());
    return dataSourceTableTreeList;
  }
  
  public List<DataSourceTableTreeVO> getSchemaList(DataStructProvider dataStructProvider, Long dataSourceId, String type, String dataBaseName, Boolean isEnableCdc) {
    return new ArrayList<>();
  }
  
  public List<DataSourceTableTreeVO> getTableList(DataStructProvider dataStructProvider, String dataBaseName, Long dataSourceId) {
    List<DBTableDTO> dbTableList = dataStructProvider.getTablesOrViews(FrameConst.FALSE.intValue(), null, buildQueryModelDto(), dataStructProvider.currentDataSource.getDbSchema());
    return (List<DataSourceTableTreeVO>)dbTableList.stream().map(dBTable -> buildDataSourceTableVO(dataBaseName, null, dBTable.getTableName(), dataSourceId, dataStructProvider.getDbType(), DCConst.DirectoryType.DATATABLE))
      .collect(Collectors.toList());
  }
  
  public List<DataSourceTableTreeVO> getDataSourceTableTreeVO(Long dataSourceId, String platCode, String tokenId) throws Exception {
    List<DataSourceTableTreeVO> dataBaseList = getDataBaseList(dataSourceId, platCode, tokenId, Boolean.FALSE);
    DataStructProvider dataStructProvider = getDataStructProvider(dataSourceId, platCode, tokenId, null, null);
    return buildDataSourceTableTree(dataBaseList, dataStructProvider, platCode);
  }
  
  private List<DataSourceTableTreeVO> buildDataSourceTableTree(List<DataSourceTableTreeVO> dataBaseList, DataStructProvider dataStructProvider, String platCode) {
    for (DataSourceTableTreeVO dataSourceTableTreeVO : dataBaseList) {
      dataStructProvider.currentDataSource.setDbName(dataSourceTableTreeVO.getSourceDatabaseName());
      List<DataSourceTableTreeVO> dataSourceChild = getDataSourceChild(dataSourceTableTreeVO, dataStructProvider, platCode);
      dataSourceTableTreeVO.setChildNodes(dataSourceChild);
    } 
    return dataBaseList;
  }
  
  private List<DataSourceTableTreeVO> getDataSourceChild(DataSourceTableTreeVO dataSourceTableTree, DataStructProvider dataStructProvider, String platCode) {
    List<DBTableDTO> dbTableList = dataStructProvider.getTablesOrViews(FrameConst.FALSE.intValue(), null, buildQueryModelDto(), dataStructProvider.currentDataSource.getDbSchema());
    return (List<DataSourceTableTreeVO>)dbTableList.stream().map(dBTable -> buildDataSourceTableVO(dataSourceTableTree.getDirectoryName(), null, dBTable.getTableName(), dataSourceTableTree.getDataSourceId(), dataSourceTableTree.getDatabaseBaseType(), DCConst.DirectoryType.DATATABLE))
      .collect(Collectors.toList());
  }
  
  public QueryModelDTO buildQueryModelDto() {
    QueryModelDTO queryModelDTO = new QueryModelDTO();
    List<SortModelDTO> sortModelDTOList = new ArrayList<>();
    SortModelDTO sortModelDTO = new SortModelDTO();
    sortModelDTO.setSortType(Integer.valueOf(0));
    sortModelDTO.setFieldName("tableName");
    sortModelDTOList.add(sortModelDTO);
    queryModelDTO.setSortModels(sortModelDTOList);
    return queryModelDTO;
  }
}
